#ifndef _KINPUTLINE_H_
#define _KINPUTLINE_H_


#include <qdialog.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>


class KInputLine : public QDialog
{
  Q_OBJECT
  
public:

  KInputLine(QWidget *parent=0, const QString & text = QString::null, const QString & init = QString::null);
  ~KInputLine() {};

  QString getText() { return lineedit->text(); };
  
private:
  QLabel *label;
  QLineEdit *lineedit;
  QPushButton *ok, *cancel;          
};

#endif
